# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_paketkoll_global_optspecs
	string join \n trust-mtime config-files= b/backend= f/format= h/help V/version
end

function __fish_paketkoll_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_paketkoll_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_paketkoll_using_subcommand
	set -l cmd (__fish_paketkoll_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c paketkoll -n "__fish_paketkoll_needs_command" -l config-files -d 'Include config files in the check' -r -f -a "include\t'Include config files in check'
exclude\t'Exclude config files in check'
only\t'Only check config files'"
complete -c paketkoll -n "__fish_paketkoll_needs_command" -s b -l backend -d 'Which package manager backend to use' -r -f -a "auto\t'Select based on current distro'
arch-linux\t'Backend for Arch Linux and derived distros (pacman)'
debian\t'Backend for Debian and derived distros (dpkg/apt)'
flatpak\t'Backend for Flatpak (EXPERIMENTAL)'"
complete -c paketkoll -n "__fish_paketkoll_needs_command" -s f -l format -d 'Output format to use' -r -f -a "human\t'Human-readable output'
json\t'JSON formatted output'"
complete -c paketkoll -n "__fish_paketkoll_needs_command" -l trust-mtime -d 'Trust mtime (don\'t check checksum if it matches)'
complete -c paketkoll -n "__fish_paketkoll_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c paketkoll -n "__fish_paketkoll_needs_command" -s V -l version -d 'Print version'
complete -c paketkoll -n "__fish_paketkoll_needs_command" -f -a "check" -d 'Check package files'
complete -c paketkoll -n "__fish_paketkoll_needs_command" -f -a "check-unexpected" -d 'Check package files and search for unexpected files'
complete -c paketkoll -n "__fish_paketkoll_needs_command" -f -a "installed-packages" -d 'Get a list of installed packages'
complete -c paketkoll -n "__fish_paketkoll_needs_command" -f -a "owns" -d 'Find package that owns a given file'
complete -c paketkoll -n "__fish_paketkoll_needs_command" -f -a "original-file" -d 'Get the original content of a file'
complete -c paketkoll -n "__fish_paketkoll_needs_command" -f -a "debug-package-file-data"
complete -c paketkoll -n "__fish_paketkoll_using_subcommand check" -s h -l help -d 'Print help'
complete -c paketkoll -n "__fish_paketkoll_using_subcommand check" -s V -l version -d 'Print version'
complete -c paketkoll -n "__fish_paketkoll_using_subcommand check-unexpected" -l ignore -d 'Paths to ignore (apart from built in ones). Basic globs are supported. Use ** to match any number of path components' -r
complete -c paketkoll -n "__fish_paketkoll_using_subcommand check-unexpected" -l canonicalize -d 'Should paths be canonicalized before checking? If you get many false positives, try this. Required on Debian due to lack of /usr merge'
complete -c paketkoll -n "__fish_paketkoll_using_subcommand check-unexpected" -s h -l help -d 'Print help'
complete -c paketkoll -n "__fish_paketkoll_using_subcommand check-unexpected" -s V -l version -d 'Print version'
complete -c paketkoll -n "__fish_paketkoll_using_subcommand installed-packages" -s h -l help -d 'Print help'
complete -c paketkoll -n "__fish_paketkoll_using_subcommand installed-packages" -s V -l version -d 'Print version'
complete -c paketkoll -n "__fish_paketkoll_using_subcommand owns" -s h -l help -d 'Print help'
complete -c paketkoll -n "__fish_paketkoll_using_subcommand owns" -s V -l version -d 'Print version'
complete -c paketkoll -n "__fish_paketkoll_using_subcommand original-file" -l package -d 'Package to query' -r
complete -c paketkoll -n "__fish_paketkoll_using_subcommand original-file" -s h -l help -d 'Print help'
complete -c paketkoll -n "__fish_paketkoll_using_subcommand original-file" -s V -l version -d 'Print version'
complete -c paketkoll -n "__fish_paketkoll_using_subcommand debug-package-file-data" -s h -l help -d 'Print help'
complete -c paketkoll -n "__fish_paketkoll_using_subcommand debug-package-file-data" -s V -l version -d 'Print version'
